form_page — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »
- pages »

# form_page

class `camelot.view.wizard.pages.form_page.` `FormPage`(parent=None)

  FormPage is a generic wizard page that displays a form for an object in a wizard page, subclass this class to use it. The class attribute ‘Data’ should be the class of the object to be used to store the form information.

  To access the data stored by the wizard form into a data object, use its get_data method.

  The ‘Next’ button will only be activated when the form is complete.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- wizard »
- pages »

Comments
blog comments powered by Disqus